"use strict";
var http = require('http');
var debug = require('debug')('jenkins:job');
var Promise = require('bluebird');
var buildresult = require('./buildresult');
(function (JobStatus) {
    JobStatus[JobStatus["Disabled"] = 0] = "Disabled";
    JobStatus[JobStatus["NotBuilt"] = 1] = "NotBuilt";
    JobStatus[JobStatus["Success"] = 2] = "Success";
    JobStatus[JobStatus["Failure"] = 3] = "Failure";
    JobStatus[JobStatus["Unknown"] = 4] = "Unknown";
})(exports.JobStatus || (exports.JobStatus = {}));
var JobStatus = exports.JobStatus;
function fromJson(json) {
    var status = JobStatus.Unknown;
    switch (json.color) {
        case "disabled":
            status = JobStatus.Disabled;
            break;
        case "notbuilt":
            status = JobStatus.NotBuilt;
            break;
        case "blue":
            status = JobStatus.Success;
            break;
        case "red":
            status = JobStatus.Failure;
            break;
        default:
            status = JobStatus.Unknown;
            break;
    }
    var job = new Job(json.name, status, json.url);
    return job;
}
exports.fromJson = fromJson;
function fromName(serverUrl, jobName) {
    var jobUrl = serverUrl + '/job/' + jobName + '/api/json';
    return fromUrl(jobUrl);
}
exports.fromName = fromName;
function fromUrl(jobUrl) {
    return new Promise(function (resolve, reject) {
        http.get(jobUrl, function (res) {
            debug('getJob status code: ' + res.statusCode);
            var responseBody = '';
            res.on('data', function (chunk) {
                responseBody += chunk;
            });
            res.on('end', function () {
                var json = JSON.parse(responseBody);
                var job = fromJson(json);
                resolve(job);
            });
        });
    });
}
exports.fromUrl = fromUrl;
var Job = (function () {
    function Job(name, status, rootUrl) {
        this.name = name;
        this.status = status;
        this.rootUrl = rootUrl;
    }
    Job.prototype.getBuildResults = function () {
        var self = this;
        return new Promise(function (resolve, reject) {
            if (self.status === JobStatus.NotBuilt || self.status === JobStatus.Disabled) {
                reject(new Error('Job \'' + self.name + '\' status is ' + JobStatus[self.status]));
            }
            else {
                var buildResultsUrl = self.rootUrl + 'api/json?tree=builds[number,result,url,fullDisplayName,timestamp,estimatedDuration,duration,builtOn,building]';
                http.get(buildResultsUrl, function (res) {
                    debug('getBuildResults for \'' + self.name + '\' status code: ' + res.statusCode);
                    if (res.statusCode !== 200) {
                        reject(new Error('Could not get build results'));
                    }
                    else {
                        var responseBody = '';
                        res.on('data', function (chunk) {
                            responseBody += chunk;
                        });
                        res.on('end', function () {
                            try {
                                var json = JSON.parse(responseBody);
                                Promise.map(json.builds, function (jsonResult) {
                                    self.buildResults = [];
                                    var b = buildresult.fromJson(jsonResult);
                                    self.buildResults.push(b);
                                    return b;
                                }).then(resolve);
                            }
                            catch (err) {
                                var error = new Error('Could not parse JSON for ' + self.name + ': ' + err.message);
                                error.stack = err.stack;
                                reject(error);
                            }
                        });
                    }
                });
            }
        });
    };
    ;
    return Job;
}());
exports.Job = Job;
//# sourceMappingURL=job.js.map